@@ -1,6 +1,5 @@
-from ai_transformersx import TaskArguments
 from torch.utils.data import Dataset
-from transformers import torch_distributed_zero_first, PretrainedConfig
+from transformers import torch_distributed_zero_first
 from typing import List, Optional
 
 from .task_data_converter import TaskDataConverter
@@ -28,8 +27,8 @@ class TaskDatasetGenerator:
 
     def __generate_features(self, limit_length: Optional[int] = None, evaluate=False):
         examples = (
-            self._processor.get_dev_examples(limit_length) if evaluate
+            self._processor.get_eval_examples(limit_length) if evaluate
             else self._processor.get_train_examples(limit_length)
         )
 
-        return self._converter.convert(examples, evaluate)
+        return self._converter.convert(examples)
